@@ -2,29 +2,25 @@
 
 import os
 import gc
-import pandas as pd
-import numpy as np
 import itertools
-import multiprocessing
+import IPython.display
+from io import BytesIO
+from PIL import Image
 from collections import defaultdict, Counter
-from tqdm import tqdm
-from sklearn import preprocessing
 import datetime as datetime
 
+import pandas as pd
+import numpy as np
+from tqdm import tqdm
+from sklearn import preprocessing
 import seaborn as sns
 import plotly
 import plotly.graph_objs as go
 import plotly.express as px
 from plotly.offline import iplot
 from wordcloud import WordCloud
-import IPython.display
-from io import BytesIO
-from PIL import Image
 import networkx as nx
 from networkx.algorithms import community
-import gensim
-import pyLDAvis.gensim
-pyLDAvis.enable_notebook()
 
 TTF_FILE_NAME = str(os.path.dirname(__file__)) + '/data/mplus-1c-regular.ttf'
 
@@ -701,44 +697,6 @@ class NLPlot():
         gc.collect()
         return fig
 
-    def ldavis(self, num_topics, passes, save=False) -> pyLDAvis:
-        """Plots of pyLDAvis
-
-        cf: https://github.com/bmabey/pyLDAvis
-
-        Args:
-            num_topics (int): The number of requested latent topics to be extracted from the training corpus.
-            passes (int): Number of passes through the corpus during training.
-            save (bool): Whether or not to save the HTML file.
-
-        Returns:
-            pyLDAvis: Figure of a pyLDAvis
-
-        """
-
-        workers = multiprocessing.cpu_count()
-        workers = workers if workers == 1 else int(workers/2)
-
-        dic = gensim.corpora.Dictionary(self.df[self.target_col])
-        bow_corpus = [dic.doc2bow(doc) for doc in self.df[self.target_col]]
-
-        # cf. https://radimrehurek.com/gensim/models/ldamodel.html
-        lda_model = gensim.models.LdaMulticore(bow_corpus,
-                                               num_topics=num_topics,
-                                               id2word=dic,
-                                               passes=passes,
-                                               workers=workers,
-                                               random_state=0)
-
-        vis = pyLDAvis.gensim.prepare(lda_model, bow_corpus, dic)
-
-        if save:
-            date = str(pd.to_datetime(datetime.datetime.now())).split(' ')[0]
-            filename = date + '_' + 'pyldavis.html'
-            pyLDAvis.save_html(vis, filename)
-
-        return vis
-
     def save_plot(self, fig, title) -> None:
         """Save the HTML file
 
